@@ -1,17 +1,16 @@
-
 type ('a, 'b) t =
   { dir : 'a * 'b
   ; quantity : ('a, 'b) t
   ; price : int * 'a
   ; mutable cancelled : bool
   }
-[@@deriving fields]
+[@@deriving fields ~getters ~setters]
 
 type foo =
   { a : [ `Bar | `Baz of string ]
   ; b : int
   }
-[@@deriving fields]
+[@@deriving fields ~getters ~setters]
 
 module Private_in_mli = struct
   type ('a, 'b) t =
@@ -20,7 +19,7 @@ module Private_in_mli = struct
     ; price : int * 'a
     ; mutable cancelled : bool
     }
-  [@@deriving fields]
+  [@@deriving fields ~getters ~setters]
 end
 
 module Private_in_ml = struct
@@ -30,5 +29,5 @@ module Private_in_ml = struct
     ; price : int * 'a
     ; mutable cancelled : bool
     }
-  [@@deriving fields]
+  [@@deriving fields ~getters ~setters]
 end
